==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/StochRSIIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StochRSIIndicatorStrategy } from "./StochRSIIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let StochRSIIndicator = /*@__PURE__*/ (() => {
    class StochRSIIndicator extends StrategyBasedIndicator {
        bg() {
            return new StochRSIIndicator();
        }
        get_yz() {
            return new StochRSIIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return StochRSIIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get zk() {
            return typeGetValue(this.c(StochRSIIndicator.zl));
        }
        set zk(a) {
            this.h(StochRSIIndicator.zl, a);
        }
        y5() {
            return this.zk;
        }
        ze(a) {
            this.zk = a;
        }
    }
    StochRSIIndicator.$t = markType(StochRSIIndicator, 'StochRSIIndicator', StrategyBasedIndicator.$);
    StochRSIIndicator.zl = StrategyBasedIndicator.zh(14, StochRSIIndicator.$);
    return StochRSIIndicator;
})();

==> igniteui-angular-charts-17.3.0.tgz: package/esm2015/lib/StochRSIIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StochRSIIndicatorStrategy } from "./StochRSIIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let StochRSIIndicator = /*@__PURE__*/ (() => {
    class StochRSIIndicator extends StrategyBasedIndicator {
        bc() {
            return new StochRSIIndicator();
        }
        get_y0() {
            return new StochRSIIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return StochRSIIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get zl() {
            return typeGetValue(this.c(StochRSIIndicator.zm));
        }
        set zl(a) {
            this.h(StochRSIIndicator.zm, a);
        }
        y6() {
            return this.zl;
        }
        zf(a) {
            this.zl = a;
        }
    }
    StochRSIIndicator.$t = markType(StochRSIIndicator, 'StochRSIIndicator', StrategyBasedIndicator.$);
    StochRSIIndicator.zm = StrategyBasedIndicator.zi(14, StochRSIIndicator.$);
    return StochRSIIndicator;
})();
